import torch
import torch.nn as nn
import torch.nn.functional as F
from resnetSmall import ResNet, ResidualBlock
import sys

class Cifar10ResNet(torch.nn.Module):
    """
    This class is a wrapper for a custom ResNet model.
    """
    def __init__(self):

        super(Cifar10ResNet, self).__init__()
        self.model = ResNet(pretrained=True)
        self.model.eval()

    def forward(self, input):
        """
        The forward function for this nn.Module will pass the input tensor to the ResNet
        forward function. An integer from 0 - 9 will be returned indicating which object has
        been detected. If a plane is detected, the forward function returns a tensor of ones.
        Otherwise, it returns a tensor of zeros.

        :param input: A torch.Tensor of size 1 x 3 x H x W representing the input image
        :return: A torch.Tensor of size 1 x 1 x H x W of zeros or ones
        """
        modelOutput = self.model.forward(input)
        modelLabel = int(torch.argmax(modelOutput[0]))

        plane = 0
        if modelLabel == plane:
          output = torch.ones(1, 1, input.shape[2], input.shape[3])
        else:
          output = torch.zeros(1, 1, input.shape[2], input.shape[3])
        return output


def main():
    resnet = Cifar10ResNet()
    module = torch.jit.script(resnet)
    module.save('cifar10_detector.pt')


if __name__ == '__main__':
    main()
